import hashlib

def id_to_obfuscated_phone(account_id):
    """
    将TT语音账号ID转换为模糊的手机号显示
    
    参数:
        account_id (str/int): 用户的真实TT语音账号ID
        
    返回:
        str: 模糊处理的手机号，例如 '138****1234'
        
    异常:
        ValueError: 如果输入的账号ID不符合TT语音账号ID的格式或规则
    """
    # 验证账号ID是否为真实TT账号ID
    account_str = str(account_id)
    
    # 检查是否为纯数字
    if not account_str.isdigit():
        raise ValueError("TT语音账号ID必须为纯数字")
    
    # 检查长度范围 (假设真实TT账号ID在6-15位之间，根据实际情况调整)
    if len(account_str) < 6 or len(account_str) > 15:
        raise ValueError("TT语音账号ID长度不符合要求")
    
    # 检查是否为连续数字 (简单检测)
    if len(set(account_str)) == 1:
        raise ValueError("不允许使用连续相同数字的账号ID")
    
    # 检查简单递增/递减模式 (如123456, 654321等)
    if account_str in '1234567890' or account_str in '9876543210':
        raise ValueError("不允许使用简单连续数字的账号ID")
    
    # 将账号ID转换为字符串并计算哈希值以确保一致性
    hash_obj = hashlib.md5(account_str.encode())
    hash_hex = hash_obj.hexdigest()
    
    # 从哈希值中提取数字部分用于生成手机号
    numbers = [c for c in hash_hex if c.isdigit()]
    
    # 如果数字不足，用0补全
    while len(numbers) < 11:
        numbers.append('0')
    
    # 构建手机号 (假设是中国的手机号 1开头)
    phone_prefix = '1' + ''.join(numbers[1:3])  # 前三位
    phone_suffix = ''.join(numbers[-4:])       # 后四位
    
    # 返回模糊处理的手机号
    return f"{phone_prefix}****{phone_suffix}"

# 示例使用
if __name__ == "__main__":
    # 测试几个账号ID
    test_ids = ["783709"]  # 替换为真实TT账号ID
    
    for account_id in test_ids:
        try:
            obfuscated_phone = id_to_obfuscated_phone(account_id)
            print(f"顺丰t反账号ID: {account_id} -> 模糊手机号: {obfuscated_phone}")
        except ValueError as e:
            print(f"错误: {e}")